
//
// This source file is part of appleseed.
// Visit https://appleseedhq.net/ for additional information and resources.
//
// This software is released under the MIT license.
//
// Copyright (c) 2017-2018 Luis Barrancos, The appleseedhq Organization
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
//

#pragma once


//
// Reference:
//
//      A Continuity Study of the CIE L* Function
//
//      http://www.brucelindbloom.com/index.html?ColorDifferenceCalcHelp.html
//

#define CIE_E   (216.0 / 24389.0)
#define CIE_K   (24389.0 / 27.0)


//
// Reference:
//
//      D50,D55,D60,D65,D75,DCI illuminants xy and xyz chromaticity coordinates
//
//      https://en.wikipedia.org/wiki/Standard_illuminant
//

#define D50_WHITEPOINT_CIE1931_2DEG_xy      0.34567, 0.35850
#define D50_WHITEPOINT_CIE1931_2DEG_xyz     0.34567, 0.35850, 0.29583

#define D55_WHITEPOINT_CIE1931_2DEG_xy      0.33242, 0.34743
#define D55_WHITEPOINT_CIE1931_2DEG_xyz     0.33242, 0.34743, 0.32015

#define D60_WHITEPOINT_CIE1931_2DEG_xy      0.32168, 0.33767
#define D60_WHITEPOINT_CIE1931_2DEG_xyz     0.32168, 0.33767, 0.34065

#define D65_WHITEPOINT_CIE1931_2DEG_xy      0.31270, 0.32900
#define D65_WHITEPOINT_CIE1931_2DEG_xyz     0.31270, 0.32900, 0.35830

#define D75_WHITEPOINT_CIE1931_2DEG_xy      0.29902, 0.31485
#define D75_WHITEPOINT_CIE1931_2DEG_xyz     0.29902, 0.31485, 0.38613

#define DCIP3_WHITEPOINT_CIE1931_2DEG_xy    0.31400, 0.35100
#define DCIP3_WHITEPOINT_CIE1931_2DEG_xyz   0.31400, 0.35100, 0.33500

#define ILLUMINANT_E_WHITEPOINT_xy          0.33333, 0.33333
#define ILLUMINANT_E_WHITEPOINT_xyz         0.33333, 0.33333, 0.33333


//
// Reference:
//
//      BT.601: Studio Encoding Parameters Of Digital Television For Standard
//      4:3 And Wide Screen 16:9 Aspect Ratios
//
//      https://www.itu.int/rec/R-REC-BT.601-7-201103-I/en
//

#define REC601_CHROMATICITIES_Rxyz          0.640, 0.330, 0.030
#define REC601_CHROMATICITIES_Gxyz          0.290, 0.600, 0.110
#define REC601_CHROMATICITIES_Bxyz          0.150, 0.060, 0.790
#define REC601_CHROMATICITIES_Wxyz          D65_WHITEPOINT_CIE1931_2DEG_xyz


//
// Reference:
//
//      BT.709: Parameter Values For The HDTV Standards For Production And
//      International Programme Exchange
//
//      https://www.itu.int/rec/R-REC-BT.709/en
//

#define REC709_CHROMATICITIES_Rxyz          0.640, 0.330, 0.030
#define REC709_CHROMATICITIES_Gxyz          0.300, 0.600, 0.100
#define REC709_CHROMATICITIES_Bxyz          0.150, 0.060, 0.790
#define REC709_CHROMATICITIES_Wxyz          D65_WHITEPOINT_CIE1931_2DEG_xyz


//
// Reference:
//
//      Adobe RGB (1998) Color Image Encoding, version 2005-05, May 2005
//
//      https://www.adobe.com/digitalimag/adobergb.html
//

#define ADOBERGB98_CHROMATICITIES_Rxyz      0.640, 0.330, 0.030
#define ADOBERGB98_CHROMATICITIES_Gxyz      0.210, 0.710, 0.080
#define ADOBERGB98_CHROMATICITIES_Bxyz      0.150, 0.060, 0.790
#define ADOBERGB98_CHROMATICITIES_Wxyz      D65_WHITEPOINT_CIE1931_2DEG_xyz


//
// Reference:
//
//      BT.2020 Parameter Values For Ultra-High Definition Television Systems
//      For Production And International Programme Exchange
//
//      https://www.itu.int/rec/R-REC-BT.2020/en
//

#define REC2020_CHROMATICITIES_Rxyz         0.708, 0.292, 0.000
#define REC2020_CHROMATICITIES_Gxyz         0.170, 0.797, 0.033
#define REC2020_CHROMATICITIES_Bxyz         0.131, 0.046, 0.823
#define REC2020_CHROMATICITIES_Wxyz         D65_WHITEPOINT_CIE1931_2DEG_xyz


//
// Reference:
//
//      TB-2014-004: Informative Notes On SMPTE ST 2065-1 - Academy Color
//      Encoding Specification (ACES)
//
//      http://j.mp/TB-2014-004
//

#define ACES_AP0_CHROMATICITIES_Rxyz        0.7347, 0.2653, 0.0000
#define ACES_AP0_CHROMATICITIES_Gxyz        0.0000, 1.0000, 0.0000
#define ACES_AP0_CHROMATICITIES_Bxyz        0.0001, -0.077, 1.0769
#define ACES_AP0_CHROMATICITIES_Wxyz        D60_WHITEPOINT_CIE1931_2DEG_xyz


//
// Reference:
//
//      S-2014-004: ACEScg - A Working Space For CGI Render And Compositing
//
//      http://j.mp/S-2014-004
//

#define ACESCG_AP1_CHROMATICITIES_Rxyz      0.7130, 0.2930, -0.006
#define ACESCG_AP1_CHROMATICITIES_Gxyz      0.1650, 0.8300, 0.0050
#define ACESCG_AP1_CHROMATICITIES_Bxyz      0.1280, 0.0440, 0.8280
#define ACESCG_AP1_CHROMATICITIES_Wxyz      D60_WHITEPOINT_CIE1931_2DEG_xyz


//
// Reference:
//
//      Digital Cinema System Specification Version 1.1, Colorimetry, page 13
//
//      http://www.dcimovies.com/archives/spec_v1_1/
//

#define DCIP3_CHROMATICITIES_Rxyz           0.6800, 0.3200, 0.0000
#define DCIP3_CHROMATICITIES_Gxyz           0.2650, 0.6900, 0.0450
#define DCIP3_CHROMATICITIES_Bxyz           0.1500, 0.0600, 0.7900
#define DCIP3_CHROMATICITIES_Wxyz           DCIP3_WHITEPOINT_CIE1931_2DEG_xyz


//
// Precomputed RGB<>CIEXYZ matrices
//
//      Created with Colour, http://colour-science.org/
//      with special thanks to Thomas Mansecal and the Colour developers.
//
//      Matrices chromatically adapted using the Bradford CAT where appropriate.
//


//
// Rec.601: D65, D65 to D60, D65 to DCI, and system default
//

#define RGB_TO_XYZ_REC601_D65_R0        0.43055381, 0.34154980, 0.17835231
#define RGB_TO_XYZ_REC601_D65_R1        0.22200431, 0.70665477, 0.07134092
#define RGB_TO_XYZ_REC601_D65_R2        0.02018221, 0.12955337, 0.93932217

#define XYZ_TO_RGB_REC601_D65_R0        3.06336109,-1.39339017,-0.47582374
#define XYZ_TO_RGB_REC601_D65_R1       -0.96924364, 1.87596750, 0.04155506
#define XYZ_TO_RGB_REC601_D65_R2        0.06786105,-0.22879927, 1.06908962

#define REC601_D65_LUMINANCE_COEFFS     RGB_TO_XYZ_REC601_D65_R1

#define RGB_TO_XYZ_REC601_D65_D60_R0    0.43721929, 0.34837665, 0.16705013
#define RGB_TO_XYZ_REC601_D65_D60_R1    0.22480951, 0.70733430, 0.06785619
#define RGB_TO_XYZ_REC601_D65_D60_R2    0.01847536, 0.12211323, 0.86823660

#define XYZ_TO_RGB_REC601_D60_D65_R0    3.03334911,-1.41228620,-0.47324544
#define XYZ_TO_RGB_REC601_D60_D65_R1   -0.97098721, 1.88517303, 0.03948565
#define XYZ_TO_RGB_REC601_D60_D65_R2    0.07201742,-0.23508807, 1.15627660

#define REC601_D60_LUMINANCE_COEFFS     RGB_TO_XYZ_REC601_D65_D60_R1

#define RGB_TO_XYZ_REC601_D65_DCI_R0    0.41670609, 0.32048049, 0.15740031
#define RGB_TO_XYZ_REC601_D65_DCI_R1    0.21720295, 0.71755742, 0.06523963
#define RGB_TO_XYZ_REC601_D65_DCI_R2    0.01758496, 0.11874324, 0.81808775

#define XYZ_TO_RGB_REC601_DCI_D65_R0    3.09967787,-1.30290336,-0.49247693
#define XYZ_TO_RGB_REC601_DCI_D65_R1   -0.94467399, 1.80933334, 0.03746756
#define XYZ_TO_RGB_REC601_DCI_D65_R2    0.07048868,-0.23461370, 1.22751034

#define REC601_DCI_LUMINANCE_COEFFS     RGB_TO_XYZ_REC601_D65_DCI_R1

#define RGB_TO_XYZ_REC601_R0            RGB_TO_XYZ_REC601_D65_R0
#define RGB_TO_XYZ_REC601_R1            RGB_TO_XYZ_REC601_D65_R1
#define RGB_TO_XYZ_REC601_R2            RGB_TO_XYZ_REC601_D65_R2

#define XYZ_TO_RGB_REC601_R0            XYZ_TO_RGB_REC601_D65_R0
#define XYZ_TO_RGB_REC601_R1            XYZ_TO_RGB_REC601_D65_R1
#define XYZ_TO_RGB_REC601_R2            XYZ_TO_RGB_REC601_D65_R2

#define REC601_LUMINANCE_COEFFS         RGB_TO_XYZ_REC601_R1


//
// Rec.709: D65, D65 to D60, D65 to DCI, and system default
//

#define RGB_TO_XYZ_REC709_D65_R0        0.41239080,  0.35758434,  0.18048079
#define RGB_TO_XYZ_REC709_D65_R1        0.21263901,  0.71516868,  0.07219232
#define RGB_TO_XYZ_REC709_D65_R2        0.01933082,  0.11919478,  0.95053215

#define XYZ_TO_RGB_REC709_D65_R0        3.24096994, -1.53738318, -0.49861076
#define XYZ_TO_RGB_REC709_D65_R1       -0.96924364,  1.87596750,  0.04155506
#define XYZ_TO_RGB_REC709_D65_R2        0.05563008, -0.20397696,  1.05697151

#define REC709_D65_LUMINANCE_COEFFS     RGB_TO_XYZ_REC709_D65_R1

#define RGB_TO_XYZ_REC709_D65_D60_R0    0.41877509,  0.36482725,  0.16904373
#define RGB_TO_XYZ_REC709_D65_D60_R1    0.21532587,  0.71600814,  0.06866599
#define RGB_TO_XYZ_REC709_D65_D60_R2    0.01769597,  0.11253097,  0.87859824

#define XYZ_TO_RGB_REC709_D60_D65_R0    3.20971293, -1.55751688, -0.49582777
#define XYZ_TO_RGB_REC709_D60_D65_R1   -0.97098721,  1.88517303,  0.03948565
#define XYZ_TO_RGB_REC709_D60_D65_R2    0.05971687, -0.21008302,  1.14310586

#define REC709_D60_LUMINANCE_COEFFS     RGB_TO_XYZ_REC709_D65_D60_R1

#define RGB_TO_XYZ_REC709_D65_DCI_R0    0.39912725,  0.33618090,  0.15927875
#define RGB_TO_XYZ_REC709_D65_DCI_R1    0.20804019,  0.72594160,  0.06601820
#define RGB_TO_XYZ_REC709_D65_DCI_R2    0.01684314,  0.10972191,  0.82785091

#define XYZ_TO_RGB_REC709_DCI_D65_R0    3.27780410, -1.43997625, -0.51581739
#define XYZ_TO_RGB_REC709_DCI_D65_R1   -0.94467399,  1.80933334,  0.03746756
#define XYZ_TO_RGB_REC709_DCI_D65_R2    0.05851649, -0.21050866,  1.21347571

#define REC709_DCI_LUMINANCE_COEFFS     RGB_TO_XYZ_REC709_D65_DCI_R1

#define RGB_TO_XYZ_REC709_R0            RGB_TO_XYZ_REC709_D65_R0
#define RGB_TO_XYZ_REC709_R1            RGB_TO_XYZ_REC709_D65_R1
#define RGB_TO_XYZ_REC709_R2            RGB_TO_XYZ_REC709_D65_R2

#define XYZ_TO_RGB_REC709_R0            XYZ_TO_RGB_REC709_D65_R0
#define XYZ_TO_RGB_REC709_R1            XYZ_TO_RGB_REC709_D65_R1
#define XYZ_TO_RGB_REC709_R2            XYZ_TO_RGB_REC709_D65_R2

#define REC709_LUMINANCE_COEFFS         RGB_TO_XYZ_REC709_R1


//
// Adobe RGB (1998): D65, D65 to D60, D65 to DCI, and system default
//

#define RGB_TO_XYZ_ADOBERGB_D65_R0      0.57667,  0.18556,  0.18823
#define RGB_TO_XYZ_ADOBERGB_D65_R1      0.29734,  0.62736,  0.07529
#define RGB_TO_XYZ_ADOBERGB_D65_R2      0.02703,  0.07069,  0.99134

#define XYZ_TO_RGB_ADOBERGB_D65_R0      2.04159, -0.56501, -0.34473
#define XYZ_TO_RGB_ADOBERGB_D65_R1     -0.96924,  1.87597,  0.04156
#define XYZ_TO_RGB_ADOBERGB_D65_R2      0.01344, -0.11836,  1.01517

#define ADOBERGB_D65_LUMINANCE_COEFFS   RGB_TO_XYZ_ADOBERGB_D65_R1

#define RGB_TO_XYZ_ADOBERGB_D65_D60_R0  0.58559752,  0.19075066,  0.17630193
#define RGB_TO_XYZ_ADOBERGB_D65_D60_R1  0.30109721,  0.62728053,  0.0716123
#define RGB_TO_XYZ_ADOBERGB_D65_D60_R2  0.02474398,  0.06776538,  0.91631784

#define XYZ_TO_RGB_ADOBERGB_D60_D65_R0  2.01873297, -0.57678916, -0.3433321
#define XYZ_TO_RGB_ADOBERGB_D60_D65_R1 -0.97097442,  1.88518233,  0.03948677
#define XYZ_TO_RGB_ADOBERGB_D60_D65_R2  0.01729417, -0.12384136,  1.09767542

#define ADOBERGB_D60_LUMINANCE_COEFFS   RGB_TO_XYZ_ADOBERGB_D65_D60_R1

#define RGB_TO_XYZ_ADOBERGB_D65_DCI_R0  0.55812291,  0.17035035,  0.16611773
#define RGB_TO_XYZ_ADOBERGB_D65_DCI_R1  0.29090906,  0.64022978,  0.06885075
#define RGB_TO_XYZ_ADOBERGB_D65_DCI_R2  0.02355145,  0.06747449,  0.86339183

#define XYZ_TO_RGB_ADOBERGB_DCI_D60_R0  2.07492223, -0.51433755, -0.35820218
#define XYZ_TO_RGB_ADOBERGB_DCI_D60_R1 -0.94466041,  1.80934263,  0.03746878
#define XYZ_TO_RGB_ADOBERGB_DCI_D60_R2  0.01722631, -0.12737100,  1.16506545

#define ADOBERGB_DCI_LUMINANCE_COEFFS   RGB_TO_XYZ_ADOBERGB_D65_DCI_R1

#define RGB_TO_XYZ_ADOBERGB_R0          RGB_TO_XYZ_ADOBERGB_D65_R0
#define RGB_TO_XYZ_ADOBERGB_R1          RGB_TO_XYZ_ADOBERGB_D65_R1
#define RGB_TO_XYZ_ADOBERGB_R2          RGB_TO_XYZ_ADOBERGB_D65_R2

#define XYZ_TO_RGB_ADOBERGB_R0          XYZ_TO_RGB_ADOBERGB_D65_R0
#define XYZ_TO_RGB_ADOBERGB_R1          XYZ_TO_RGB_ADOBERGB_D65_R1
#define XYZ_TO_RGB_ADOBERGB_R2          XYZ_TO_RGB_ADOBERGB_D65_R2

#define ADOBERGB_LUMINANCE_COEFFS       RGB_TO_XYZ_ADOBERGB_R1


//
// Rec.2020: D65, D65 to D60, D65 to DCI, and system default
//

#define RGB_TO_XYZ_REC2020_D65_R0       0.63695805,  0.14461690,  0.16888098
#define RGB_TO_XYZ_REC2020_D65_R1       0.26270021,  0.67799807,  0.05930172
#define RGB_TO_XYZ_REC2020_D65_R2       0.00000000,  0.02807269,  1.06098506

#define XYZ_TO_RGB_REC2020_D65_R0       1.71665119, -0.35567078, -0.25336628
#define XYZ_TO_RGB_REC2020_D65_R1      -0.66668435,  1.61648124,  0.01576855
#define XYZ_TO_RGB_REC2020_D65_R2       0.01763986, -0.04277061,  0.94210312

#define REC2020_D65_LUMINANCE_COEFFS    RGB_TO_XYZ_REC2020_D65_R1

#define RGB_TO_XYZ_REC2020_D65_D60_R0   0.64686459,  0.15022105,  0.15556043
#define RGB_TO_XYZ_REC2020_D65_D60_R1   0.26712117,  0.67772486,  0.05515397
#define RGB_TO_XYZ_REC2020_D65_D60_R2  -0.00057901,  0.02871900,  0.98068519

#define XYZ_TO_RGB_REC2020_D60_D65_R0   1.69664330, -0.36553600, -0.24857090
#define XYZ_TO_RGB_REC2020_D60_D65_R1  -0.67040097,  1.62348553,  0.01503663
#define XYZ_TO_RGB_REC2020_D60_D65_R2   0.02063416, -0.04775899,  1.01910812

#define REC2020_D60_LUMINANCE_COEFFS    RGB_TO_XYZ_REC2020_D65_D60_R1

#define RGB_TO_XYZ_REC2020_D65_DCI_R0   0.61798468,  0.13029564,  0.14630658
#define RGB_TO_XYZ_REC2020_D65_DCI_R1   0.25383422,  0.69352615,  0.05263963
#define RGB_TO_XYZ_REC2020_D65_DCI_R2  -0.00072416,  0.03114189,  0.92399823

#define XYZ_TO_RGB_REC2020_DCI_D65_R0   1.74797647, -0.31678170, -0.25872905
#define XYZ_TO_RGB_REC2020_DCI_D65_R1  -0.64151364,  1.56186477,  0.01259925
#define XYZ_TO_RGB_REC2020_DCI_D65_R2   0.02299113, -0.05288843,  1.08162574

#define REC2020_DCI_LUMINANCE_COEFFS    RGB_TO_XYZ_REC2020_D65_DCI_R1

#define RGB_TO_XYZ_REC2020_R0           RGB_TO_XYZ_REC2020_D65_R0
#define RGB_TO_XYZ_REC2020_R1           RGB_TO_XYZ_REC2020_D65_R1
#define RGB_TO_XYZ_REC2020_R2           RGB_TO_XYZ_REC2020_D65_R2

#define XYZ_TO_RGB_REC2020_R0           XYZ_TO_RGB_REC2020_D65_R0
#define XYZ_TO_RGB_REC2020_R1           XYZ_TO_RGB_REC2020_D65_R1
#define XYZ_TO_RGB_REC2020_R2           XYZ_TO_RGB_REC2020_D65_R2

#define REC2020_LUMINANCE_COEFFS        RGB_TO_XYZ_REC2020_R1


//
// ACES 2065-1 AP0: D60 to D65, D60, D60 to DCI, and system default
//

#define RGB_TO_XYZ_ACES_D60_D65_R0      0.93827985, -0.00445145,  0.01662752
#define RGB_TO_XYZ_ACES_D60_D65_R1      0.33736889,  0.72952157, -0.06689046
#define RGB_TO_XYZ_ACES_D60_D65_R2      0.00117395, -0.00371071,  1.09159451

#define XYZ_TO_RGB_ACES_D65_D60_R0      1.06349549,  0.00640891, -0.01580679
#define XYZ_TO_RGB_ACES_D65_D60_R1     -0.49207413,  1.36822341,  0.09133709
#define XYZ_TO_RGB_ACES_D65_D60_R2     -0.00281646,  0.00464417,  0.91641857

#define ACES_D65_LUMINANCE_COEFFS       RGB_TO_XYZ_ACES_D60_D65_R1

#define RGB_TO_XYZ_ACES_D60_R0          0.95255240,  0.00000000,  0.00009368
#define RGB_TO_XYZ_ACES_D60_R1          0.34396645,  0.72816610, -0.07213255
#define RGB_TO_XYZ_ACES_D60_R2          0.00000000,  0.00000000,  1.00882518

#define XYZ_TO_RGB_ACES_D60_R0          1.04981102,  0.00000000, -0.00009748
#define XYZ_TO_RGB_ACES_D60_R1         -0.49590302,  1.37331305,  0.09824004
#define XYZ_TO_RGB_ACES_D60_R2          0.00000000,  0.00000000,  0.99125202

#define ACES_D60_LUMINANCE_COEFFS       RGB_TO_XYZ_ACES_D60_R1

#define RGB_TO_XYZ_ACES_D60_DCI_R0      0.91107700, -0.01554636, -0.00094374
#define RGB_TO_XYZ_ACES_D60_DCI_R1      0.32288858,  0.75046991, -0.07335849
#define RGB_TO_XYZ_ACES_D60_DCI_R2     -0.00059354,  0.00487426,  0.95013523

#define XYZ_TO_RGB_ACES_DCI_D60_R0      1.08961088,  0.02255349,  0.00282360
#define XYZ_TO_RGB_ACES_DCI_D60_R1     -0.46850201,  1.32213323,  0.10161453
#define XYZ_TO_RGB_ACES_DCI_D60_R2      0.00308412, -0.00676855,  1.05196223

#define ACES_DCI_LUMINANCE_COEFFS       RGB_TO_XYZ_ACES_D60_DCI_R1

#define RGB_TO_XYZ_ACES_R0              RGB_TO_XYZ_ACES_D60_R0
#define RGB_TO_XYZ_ACES_R1              RGB_TO_XYZ_ACES_D60_R1
#define RGB_TO_XYZ_ACES_R2              RGB_TO_XYZ_ACES_D60_R2

#define XYZ_TO_RGB_ACES_R0              XYZ_TO_RGB_ACES_D60_R0
#define XYZ_TO_RGB_ACES_R1              XYZ_TO_RGB_ACES_D60_R1
#define XYZ_TO_RGB_ACES_R2              XYZ_TO_RGB_ACES_D60_R2

#define ACES_LUMINANCE_COEFFS           RGB_TO_XYZ_ACES_R1


//
// ACEScg AP1: D60 to D65, D60, D60 to DCI, and system default
//

#define RGB_TO_XYZ_ACESCG_D60_D65_R0    0.65223754,  0.12823614,  0.16998225
#define RGB_TO_XYZ_ACESCG_D60_D65_R1    0.26767218,  0.67433999,  0.05798783
#define RGB_TO_XYZ_ACESCG_D60_D65_R2   -0.00538182,  0.00136906,  1.09307051

#define XYZ_TO_RGB_ACESCG_D65_D60_R0    1.66058533, -0.31529556, -0.24150933
#define XYZ_TO_RGB_ACESCG_D65_D60_R1   -0.65992606,  1.60839147,  0.01729859
#define XYZ_TO_RGB_ACESCG_D65_D60_R2    0.00900257, -0.00356688,  0.91364331

#define ACESCG_D65_LUMINANCE_COEFFS     RGB_TO_XYZ_ACES_D60_D65_R1

#define RGB_TO_XYZ_ACESCG_D60_R0        0.66245418,  0.13400421,  0.15618769
#define RGB_TO_XYZ_ACESCG_D60_R1        0.27222872,  0.67408177,  0.05368952
#define RGB_TO_XYZ_ACESCG_D60_R2       -0.00557465,  0.00406073,  1.01033910

#define XYZ_TO_RGB_ACESCG_D60_R0        1.64102338, -0.32480329, -0.23642470
#define XYZ_TO_RGB_ACESCG_D60_R1       -0.66366286,  1.61533159,  0.01675635
#define XYZ_TO_RGB_ACESCG_D60_R2        0.01172189, -0.00828444,  0.98839486

#define ACESCG_D60_LUMINANCE_COEFFS     RGB_TO_XYZ_ACES_D60_R1

#define RGB_TO_XYZ_ACESCG_D60_DCI_R0    0.63291936,  0.11480057,  0.14686696
#define RGB_TO_XYZ_ACESCG_D60_DCI_R1    0.25857593,  0.69028557,  0.05113851
#define RGB_TO_XYZ_ACESCG_D60_DCI_R2   -0.00544477,  0.00793126,  0.95192947

#define XYZ_TO_RGB_ACESCG_DCI_D60_R0    1.69164697, -0.27850893, -0.24603138
#define XYZ_TO_RGB_ACESCG_DCI_D60_R1   -0.63478722,  1.55408048,  0.01445056
#define XYZ_TO_RGB_ACESCG_DCI_D60_R2    0.01496466, -0.01454124,  1.04897036

#define ACESCG_DCI_LUMINANCE_COEFFS     RGB_TO_XYZ_ACES_D60_DCI_R1

#define RGB_TO_XYZ_ACESCG_R0            RGB_TO_XYZ_ACESCG_D60_R0
#define RGB_TO_XYZ_ACESCG_R1            RGB_TO_XYZ_ACESCG_D60_R1
#define RGB_TO_XYZ_ACESCG_R2            RGB_TO_XYZ_ACESCG_D60_R2

#define XYZ_TO_RGB_ACESCG_R0            XYZ_TO_RGB_ACESCG_D60_R0
#define XYZ_TO_RGB_ACESCG_R1            XYZ_TO_RGB_ACESCG_D60_R1
#define XYZ_TO_RGB_ACESCG_R2            XYZ_TO_RGB_ACESCG_D60_R2

#define ACESCG_LUMINANCE_COEFFS         RGB_TO_XYZ_ACESCG_R1


//
// DCI-P3: DCI to D65, DCI to D60, DCI, and system default
//

#define RGB_TO_XYZ_DCIP3_DCI_D65_R0     0.45925165,  0.29579179,  0.19541248
#define RGB_TO_XYZ_DCIP3_DCI_D65_R1     0.21515051,  0.70913364,  0.07571585
#define RGB_TO_XYZ_DCIP3_DCI_D65_R2     0.00027201,  0.04693951,  1.04184623

#define XYZ_TO_RGB_DCIP3_D65_DCI_R0     2.69022591, -1.09400194, -0.42508235
#define XYZ_TO_RGB_DCIP3_D65_DCI_R1    -0.82008218,  1.75048091,  0.02660195
#define XYZ_TO_RGB_DCIP3_D65_DCI_R2     0.03624575, -0.07858084,  0.95874699

#define DCIP3_D65_LUMINANCE_COEFFS      RGB_TO_XYZ_DCIP3_DCI_D65_R1

#define RGB_TO_XYZ_DCIP3_DCI_D60_R0     0.46654744,  0.30327412,  0.18282451
#define RGB_TO_XYZ_DCIP3_DCI_D60_R1     0.21828941,  0.70987208,  0.07183851
#define RGB_TO_XYZ_DCIP3_DCI_D60_R2    -0.00004540,  0.04587783,  0.96299275

#define XYZ_TO_RGB_DCIP3_D60_DCI_R0     2.66286214, -1.11031817, -0.42271645
#define XYZ_TO_RGB_DCIP3_D60_DCI_R1    -0.82282389,  1.75861719,  0.02502194
#define XYZ_TO_RGB_DCIP3_D60_DCI_R2     0.03932559, -0.08383443,  1.03721743

#define DCIP3_D60_LUMINANCE_COEFFS      RGB_TO_XYZ_DCIP3_DCI_D60_R1

#define RGB_TO_XYZ_DCIP3_DCI_R0         0.44516982,  0.27713441,  0.17228267
#define RGB_TO_XYZ_DCIP3_DCI_R1         0.20949168,  0.72159525,  0.06891307
#define RGB_TO_XYZ_DCIP3_DCI_R2        -0.00000000,  0.04706056,  0.90735539

#define XYZ_TO_RGB_DCIP3_DCI_R0         2.72539403, -1.01800301, -0.44016320
#define XYZ_TO_RGB_DCIP3_DCI_R1        -0.79516803,  1.68973205,  0.02264719
#define XYZ_TO_RGB_DCIP3_DCI_R2         0.04124189, -0.08763902,  1.10092938

#define DCIP3_DCI_LUMINANCE_COEFFS      RGB_TO_XYZ_DCIP3_DCI_R1

#define RGB_TO_XYZ_DCIP3_R0             RGB_TO_XYZ_DCIP3_DCI_R0
#define RGB_TO_XYZ_DCIP3_R1             RGB_TO_XYZ_DCIP3_DCI_R1
#define RGB_TO_XYZ_DCIP3_R2             RGB_TO_XYZ_DCIP3_DCI_R2

#define XYZ_TO_RGB_DCIP3_R0             XYZ_TO_RGB_DCIP3_DCI_R0
#define XYZ_TO_RGB_DCIP3_R1             XYZ_TO_RGB_DCIP3_DCI_R1
#define XYZ_TO_RGB_DCIP3_R2             XYZ_TO_RGB_DCIP3_DCI_R2

#define DCIP3_LUMINANCE_COEFFS          RGB_TO_XYZ_DCIP3_R1


//
// Precomputed RGB<>RGB matrices
//
//      Created with Colour, http://colour-science.org/
//      with special thanks to Thomas Mansecal and the Colour developers.
//
//      Matrices chromatically adapted using the Bradford CAT where appropriate.
//  


//
// Source:  ACES 2065-1 AP0 D60
// Target:  ACEScg AP1 D60
//          DCI-P3 DCI
//          Rec.2020 D65
//          Rec.709 D65
//

#define ACES_TO_ACESCG_X        1.45143932, -0.23651075,  -0.214928570
#define ACES_TO_ACESCG_Y       -0.07655377,  1.17622970 , -0.099675930
#define ACES_TO_ACESCG_Z        0.00831615, -0.00603245,   0.997716300

#define ACES_TO_DCIP3_X         2.15460352, -0.80849605,  -0.346107470
#define ACES_TO_DCIP3_Y        -0.17887756,  1.28056541,  -0.101687860
#define ACES_TO_DCIP3_Z         0.00862345, -0.06104539,   1.052421940

#define ACES_TO_REC2020_X       1.49040952, -0.26617092,  -0.224238600
#define ACES_TO_REC2020_Y      -0.08016750 , 1.18216712,  -0.101999600
#define ACES_TO_REC2020_Z       0.00322763, -0.03477648,   1.031548840

#define ACES_TO_REC709_X        2.52168619, -1.13413099,  -0.387555200
#define ACES_TO_REC709_Y       -0.27647991,  1.37271909,  -0.096239170
#define ACES_TO_REC709_Z       -0.01537806, -0.15297534,   1.168353400


//
// Source:  ACEScg AP1 D60
// Target:  ACES 2065-1 AP0 D60
//          DCI-P3 DCI
//          Rec.2020 D65
//          Rec.709 D65
//

#define ACESCG_TO_ACES_X        0.69545224,  0.14067870,  0.163869060
#define ACESCG_TO_ACES_Y        0.04479456,  0.85967112,  0.095534320
#define ACESCG_TO_ACES_Z       -0.00552588,  0.00402521,  1.001500670

#define ACESCG_TO_DCIP3_X       1.46412017, -0.39332704, -0.070793130
#define ACESCG_TO_DCIP3_Y      -0.06647651,  1.07529153, -0.008815010
#define ACESCG_TO_DCIP3_Z      -0.00255286, -0.0470296 ,  1.049582460

#define ACESCG_TO_REC2020_X     1.02582475, -0.02005319, -0.005771560
#define ACESCG_TO_REC2020_Y    -0.00223437,  1.00458650, -0.002352130
#define ACESCG_TO_REC2020_Z    -0.00501335, -0.02529007,  1.030303420

#define ACESCG_TO_REC709_X      1.70505099, -0.62179212, -0.083258870
#define ACESCG_TO_REC709_Y     -0.13025642,  1.14080474, -0.010548320
#define ACESCG_TO_REC709_Z     -0.02400336, -0.12896898,  1.152972330


//
// Source:  DCI-P3 DCI
// Target:  ACES 2065-1 AP0 D60
//          ACEScg AP1 D60
//          Rec.2020 D65
//          Rec.709 D60
//

#define DCIP3_TO_ACES_X         0.48978665,  0.31837604,  0.191837310
#define DCIP3_TO_ACES_Y         0.06841295,  0.82898907,  0.102597970
#define DCIP3_TO_ACES_Z        -0.00004500,  0.04547649,  0.954568500

#define DCIP3_TO_ACESCG_X       0.69472487,  0.25626448,  0.049010650
#define DCIP3_TO_ACESCG_Y       0.04297882,  0.94617577,  0.010845410
#define DCIP3_TO_ACESCG_Z       0.00361555,  0.04301947,  0.953364990

#define DCIP3_TO_REC2020_X      0.71178323,  0.24366032,  0.044556450
#define DCIP3_TO_REC2020_Y      0.04151416,  0.94984163,  0.008543210
#define DCIP3_TO_REC2020_Z     -0.00084473,  0.01910951,  0.981735220

#define DCIP3_TO_REC709_X       1.15751641, -0.15496238, -0.002554030
#define DCIP3_TO_REC709_Y      -0.04150007,  1.04556792, -0.004067850
#define DCIP3_TO_REC709_Z      -0.01805004, -0.07857827,  1.096628310


//
// Source:  Rec.2020 D65
// Target:  ACES 2065-1 AP0 D60
//          ACEScg AP1 D60
//          DCI-P3 DCI
//          Rec.709 D65
//

#define REC2020_TO_ACES_X       0.67908563,  0.15770091,  0.163213450
#define REC2020_TO_ACES_Y       0.04600200,  0.85905467,  0.094943320
#define REC2020_TO_ACES_Z      -0.00057394,  0.02846777,  0.972106170

#define REC2020_TO_ACESCG_X     0.97489498,  0.01959911,  0.005505910
#define REC2020_TO_ACESCG_Y     0.00217956,  0.99553547,  0.002284970
#define REC2020_TO_ACESCG_Z     0.00479724,  0.02453202,  0.970670740

#define REC2020_TO_DCIP3_X      1.42616651, -0.36461227, -0.061554240
#define REC2020_TO_DCIP3_Y     -0.06250624,  1.06897172, -0.006465480
#define REC2020_TO_DCIP3_Z      0.00244382, -0.02112130 , 1.018677470

#define REC2020_TO_REC709_X     1.66049100, -0.58764114, -0.072849786
#define REC2020_TO_REC709_Y    -0.12455047,  1.13289990, -0.008349420
#define REC2020_TO_REC709_Z    -0.01815076, -0.10057809,  1.118729660


//
// Source:  Rec.709 D65
// Target:  ACES 2065-1 AP0 D60
//          ACEScg AP1 D60
//          DCI-P3 DCI
//          Rec.2020 D65
//

#define REC709_TO_ACES_X        0.43963298,  0.38298870,  0.177378320
#define REC709_TO_ACES_Y        0.08977644,  0.81343943,  0.096784130
#define REC709_TO_ACES_Z        0.01754117,  0.11154655,  0.870912280

#define REC709_TO_ACESCG_X      0.6130974 ,  0.33952315,  0.047379450
#define REC709_TO_ACESCG_Y      0.07019372,  0.91635388,  0.013452400
#define REC709_TO_ACESCG_Z      0.02061559,  0.10956977,  0.869814630

#define REC709_TO_DCIP3_X       0.86857974,  0.12891914,  0.002501120
#define REC709_TO_DCIP3_Y       0.03454041,  0.96181139,  0.003648200
#define REC709_TO_DCIP3_Z       0.01677143,  0.07104000,  0.912188570

#define REC709_TO_REC2020_X     0.62740390,  0.32928304,  0.043313070
#define REC709_TO_REC2020_Y     0.06909729,  0.91954040,  0.011362320
#define REC709_TO_REC2020_Z     0.01639144,  0.08801331,  0.895595250


//
// Source:  AdobeRGB D65
// Target:  ACES 2065-1 AP0 D60
//          ACEScg AP1 D60
//          DCI-P3 DCI
//          Rec.2020 D65
//          Rec.709 D65
//

#define ADOBERGB_TO_ACES_X      0.61468418,  0.20122944,  0.18409058
#define ADOBERGB_TO_ACES_Y      0.12528579,  0.77490799,  0.09979070
#define ADOBERGB_TO_ACES_Z      0.02435179,  0.06428435,  0.91136594

#define ADOBERGB_TO_ACESCG_X    0.85731145,  0.09498172,  0.04771616
#define ADOBERGB_TO_ACESCG_Y    0.09788119,  0.88965732,  0.01242271
#define ADOBERGB_TO_ACESCG_Z    0.02865221,  0.06113640,  0.91021359

#define ADOBERGB_TO_DCIP3_X     1.22483601, -0.22693080,  0.00211609
#define ADOBERGB_TO_DCIP3_Y     0.04939707,  0.95045380,  0.00012829
#define ADOBERGB_TO_DCIP3_Z     0.02290715,  0.01775411,  0.95934202

#define ADOBERGB_TO_REC2020_X   0.87733760,  0.07749771,  0.04517467
#define ADOBERGB_TO_REC2020_Y   0.09661389,  0.89152040,  0.01184687
#define ADOBERGB_TO_REC2020_Z   0.02292001,  0.04303795,  0.93404466

#define ADOBERGB_TO_REC709_X    1.39836717, -0.39834512,  0.00000540
#define ADOBERGB_TO_REC709_Y   -0.00001032,  0.99999165, -0.00000395
#define ADOBERGB_TO_REC709_Z   -0.00000037, -0.04292695,  1.04293197
